Developer Guides
================

In the Developer Guides we discuss in depth the architecture of the SDV project and the
related libraries, while also providing clear instructions about how to extend its development
to better adapt it to your needs to contribute to the development of the libraries.

.. toctree::
    :maxdepth: 2

    overview
    contributing
